@@ -3,6 +3,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
+#include <strings.h>
 #include <syslog.h>
 #include <signal.h>
 #include <time.h>
@@ -15,6 +16,10 @@
 #include "in.ipscrompd.h"
 #include "common.h"
 
+#if defined(__svr4__) && defined(__sun__) && !defined(LOG_AUTHPRIV)
+#define LOG_AUTHPRIV LOG_AUTH
+#endif
+
 #ifndef PASS_FILE
 #define PASS_FILE "/usr/local/etc/ipscromp_pass"
 #endif
@@ -123,7 +128,7 @@ int main(int argc, char *argv[])
   response = recv_sock(STDIN_FILENO);
 
   /* strtok() inserts NULLs into a string, so we make a safe copy */
-  if ((command = strdup(response)) != NULL)
+  if (response != NULL && (command = strdup(response)) != NULL)
   {
     command       = strtok(command, " ");
     user          = strtok(NULL,    " ");
@@ -131,12 +136,18 @@ int main(int argc, char *argv[])
   }
 
   /* Check for protocol sanity */
-  if (   command == NULL
+  if (   response == NULL
+      || command == NULL
       || user == NULL
       || proto_version == NULL
       || (proto_version_num = atoi(proto_version)) <= 0
       || strcmp(command, "USER"))
   {
+    if (response == NULL)
+    {
+      response = "(null)";
+    }
+
     syslog(LOG_ERR, "Received invalid USER string '%s'", response);
     send_sock(STDOUT_FILENO, errormsgs[ERROR_PROTOCOL]);
     return 1;
